Stan Math Library: stan/math/prim/scal/fun/sign.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sign.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_SIGN_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_SIGN_HPP
3
4 namespace stan {
5 namespace math {
6
7 // returns 1 if NaN is passed in.
8 template<typename T>
9 inline int sign(const T& z) {
10 return (z == 0) ? 0 : z < 0 ? -1 : 1;
11 }
12 }
13 }
14
15 #endif
16
stan
Definition: log_sum_exp.hpp:8
stan::math::sign
int sign(const T &z)
Definition: sign.hpp:9

[ Stan Home Page ] © 2011–2016, Stan Development Team.